/*$Id: s_ac_swp.cc,v 19.12 2001/02/24 03:40:45 al Exp $ -*- C++ -*-
 * ac sweep control
 */
#include "l_compar.h"
#include "constant.h"
#include "e_cardlist.h"
#include "s_ac.h"
/*--------------------------------------------------------------------------*/
//	void	AC::sweep();
//	void	AC::first();
//	bool	AC::next();
/*--------------------------------------------------------------------------*/
void AC::sweep()
{
  head(start, stop, linswp, "Freq");
  first();
  CARD_LIST::card_list.ac_begin();
  do {
    jomega = COMPLEX(0., freq * kPIx2);
    solve();
    outdata(freq);
  } while (next());
}
/*--------------------------------------------------------------------------*/
void AC::first()
{
  freq = start;
}
/*--------------------------------------------------------------------------*/
bool AC::next()
{
  double realstop = (linswp)
    ? stop - step/100.
    : stop / pow(step,.01);
  if (!in_order(start, freq, realstop)){
    return false;
  }

  freq = (linswp)
    ? freq + step
    : freq * step;
  if (in_order(freq, start, stop)){
    return false;
  }else{
    return true;
  }
}
/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
